@@ -1,4 +1,4 @@
-// Copyright 2021 Martin Dosch.
+// Copyright Martin Dosch.
 // Use of this source code is governed by the BSD-2-clause
 // license that can be found in the LICENSE file.
 
@@ -141,7 +141,8 @@ func getCNAMECustomResolver(server string, resolver string) (string, error) {
 }
 
 func getSRVDoT(server string, srvType string,
-	resolver string) ([]SRV, error) {
+	resolver string,
+) ([]SRV, error) {
 	var records []SRV
 	var err error
 	var d tls.Dialer
@@ -168,16 +169,19 @@ func getSRVDoT(server string, srvType string,
 	}
 	if len(addr) > 0 {
 		for _, adr := range addr {
-			records = append(records, SRV{srvType,
+			records = append(records, SRV{
+				srvType,
 				adr.Target, adr.Port, adr.Priority,
-				adr.Weight})
+				adr.Weight,
+			})
 		}
 	}
 	return records, err
 }
 
 func getSRVCustomResolver(server string, srvType string,
-	resolver string) ([]SRV, error) {
+	resolver string,
+) ([]SRV, error) {
 	var records []SRV
 	var err error
 	var d net.Dialer
@@ -197,9 +201,11 @@ func getSRVCustomResolver(server string, srvType string,
 	}
 	if len(addr) > 0 {
 		for _, adr := range addr {
-			records = append(records, SRV{srvType,
+			records = append(records, SRV{
+				srvType,
 				adr.Target, adr.Port, adr.Priority,
-				adr.Weight})
+				adr.Weight,
+			})
 		}
 	}
 	return records, err
@@ -216,9 +222,11 @@ func getSRV(server string, srvType string) ([]SRV, error) {
 	}
 	if len(addr) > 0 {
 		for _, adr := range addr {
-			records = append(records, SRV{srvType,
+			records = append(records, SRV{
+				srvType,
 				adr.Target, adr.Port, adr.Priority,
-				adr.Weight})
+				adr.Weight,
+			})
 		}
 	}
 	return records, err
@@ -226,11 +234,6 @@ func getSRV(server string, srvType string) ([]SRV, error) {
 
 // LookupXmppServer returns the xmpp-server SRV records.
 func LookupXmppServer(server string) ([]SRV, error) {
-	// Look up CNAME
-	cname, err := getCNAME(server)
-	if err == nil {
-		server = cname
-	}
 	// Look up xmpp-server SRV
 	records, err := getSRV(server, "xmpp-server")
 	return records, err
@@ -238,28 +241,15 @@ func LookupXmppServer(server string) ([]SRV, error) {
 
 // LookupXmppServer returns the xmpp-server SRV records.
 func (c *Config) LookupXmppServer(server string) ([]SRV, error) {
-	var cname string
 	var records []SRV
 	var err error
 	// Look up xmpp-server SRV
 	switch {
 	case c.Resolver == "":
-		cname, err = getCNAME(server)
-		if err == nil {
-			server = cname
-		}
 		records, err = getSRV(server, "xmpp-server")
 	case c.Resolver != "" && !c.DoT:
-		cname, err = getCNAMECustomResolver(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		records, err = getSRVCustomResolver(server, "xmpp-server", c.Resolver)
 	case c.Resolver != "" && c.DoT:
-		cname, err = getCNAMEDoT(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		records, err = getSRVDoT(server, "xmpp-server", c.Resolver)
 	default:
 		return records, errors.New("xmppsrv: invalid resolver setting")
@@ -270,11 +260,6 @@ func (c *Config) LookupXmppServer(server string) ([]SRV, error) {
 
 // LookupXmppsServer returns the xmpps-server SRV records.
 func LookupXmppsServer(server string) ([]SRV, error) {
-	// Look up CNAME
-	cname, err := getCNAME(server)
-	if err == nil {
-		server = cname
-	}
 	// Look up xmpps-server SRV
 	records, err := getSRV(server, "xmpps-server")
 	return records, err
@@ -302,30 +287,17 @@ func (c *Config) LookupCNAME(server string) (string, error) {
 
 // LookupXmppsServer returns the xmpps-server SRV records.
 func (c *Config) LookupXmppsServer(server string) ([]SRV, error) {
-	var cname string
 	var records []SRV
 	var err error
 	switch {
 	case c.Resolver == "":
-		cname, err = getCNAME(server)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpps-server SRV
 		records, err = getSRV(server, "xmpps-server")
 	case c.Resolver != "" && !c.DoT:
-		cname, err = getCNAMECustomResolver(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpps-server SRV
 		records, err = getSRVCustomResolver(server, "xmpps-server",
 			c.Resolver)
 	case c.Resolver != "" && c.DoT:
-		cname, err = getCNAMEDoT(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpps-server SRV
 		records, err = getSRVDoT(server, "xmpps-server", c.Resolver)
 	default:
@@ -336,11 +308,6 @@ func (c *Config) LookupXmppsServer(server string) ([]SRV, error) {
 
 // LookupXmppClient returns the xmpp-server SRV records.
 func LookupXmppClient(server string) ([]SRV, error) {
-	// Look up CNAME
-	cname, err := getCNAME(server)
-	if err == nil {
-		server = cname
-	}
 	// Look up xmpp-client SRV
 	records, err := getSRV(server, "xmpp-client")
 	return records, err
@@ -348,30 +315,17 @@ func LookupXmppClient(server string) ([]SRV, error) {
 
 // LookupXmppClient returns the xmpp-server SRV records.
 func (c *Config) LookupXmppClient(server string) ([]SRV, error) {
-	var cname string
 	var records []SRV
 	var err error
 	switch {
 	case c.Resolver == "":
-		cname, err = getCNAME(server)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRV(server, "xmpp-client")
 	case c.Resolver != "" && !c.DoT:
-		cname, err = getCNAMECustomResolver(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRVCustomResolver(server, "xmpp-client",
 			c.Resolver)
 	case c.Resolver != "" && c.DoT:
-		cname, err = getCNAMEDoT(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRVDoT(server, "xmpp-client", c.Resolver)
 	default:
@@ -382,11 +336,6 @@ func (c *Config) LookupXmppClient(server string) ([]SRV, error) {
 
 // LookupXmppsClient returns the xmpp-server SRV records.
 func LookupXmppsClient(server string) ([]SRV, error) {
-	// Look up CNAME
-	cname, err := getCNAME(server)
-	if err == nil {
-		server = cname
-	}
 	// Look up xmpps-client SRV
 	records, err := getSRV(server, "xmpps-client")
 	return records, err
@@ -394,30 +343,17 @@ func LookupXmppsClient(server string) ([]SRV, error) {
 
 // LookupXmppsClient returns the xmpp-server SRV records.
 func (c *Config) LookupXmppsClient(server string) ([]SRV, error) {
-	var cname string
 	var records []SRV
 	var err error
 	switch {
 	case c.Resolver == "":
-		cname, err = getCNAME(server)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpps-client SRV
 		records, err = getSRV(server, "xmpps-client")
 	case c.Resolver != "" && !c.DoT:
-		cname, err = getCNAMECustomResolver(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpps-client SRV
 		records, err = getSRVCustomResolver(server, "xmpps-client",
 			c.Resolver)
 	case c.Resolver != "" && c.DoT:
-		cname, err = getCNAMEDoT(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpps-client SRV
 		records, err = getSRVDoT(server, "xmpps-client", c.Resolver)
 	default:
@@ -432,11 +368,6 @@ func LookupClient(server string) ([]SRV, error) {
 	var records, records2 []SRV
 	var err, err2 error
 	rand.Seed(time.Now().UnixNano())
-	// Look up CNAME
-	cname, err := getCNAME(server)
-	if err == nil {
-		server = cname
-	}
 	// Look up xmpp-client SRV
 	records, err = getSRV(server, "xmpp-client")
 	// Look up xmpps-client SRV records.
@@ -449,59 +380,41 @@ func LookupClient(server string) ([]SRV, error) {
 	default:
 		records = append(records, records2...)
 	}
-	switch {
-	case err != nil && err2 != nil:
+	if err != nil && err2 != nil {
 		return records, fmt.Errorf("failure in xmpp-client lookup: %v\n"+
 			"failure in xmpps-client lookup: %v", err, err2)
-	case err != nil:
-		return records, err
-	case err2 != nil:
-		return records, err2
 	}
 	switch len(records) {
 	case 0:
 		return records, errors.New("no client records found")
 	case 1:
-		return records, err
+		return records, nil
 	default:
 		// Sort xmpp- and xmpps-client SRV records according to the priority
 		// and weight.
 		sort.Sort(byPriority(records))
 	}
-	return records, err
+	return records, nil
 }
 
 // LookupClient returns the xmpp-client and xmpps-client SRV records sorted by
 // priority and weight.
 func (c *Config) LookupClient(server string) ([]SRV, error) {
-	var cname string
 	var records, records2 []SRV
 	var err, err2 error
 	rand.Seed(time.Now().UnixNano())
 	switch {
 	case c.Resolver == "":
-		cname, err = getCNAME(server)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRV(server, "xmpp-client")
 		// Look up xmpps-client SRV records.
 		records2, err2 = getSRV(server, "xmpps-client")
 	case c.Resolver != "" && !c.DoT:
-		cname, err = getCNAMECustomResolver(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRVCustomResolver(server, "xmpp-client", c.Resolver)
 		// Look up xmpps-client SRV records.
 		records2, err2 = getSRVCustomResolver(server, "xmpps-client", c.Resolver)
 	case c.Resolver != "" && c.DoT:
-		cname, err = getCNAMEDoT(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRVDoT(server, "xmpp-client", c.Resolver)
 		// Look up xmpps-client SRV records.
@@ -517,26 +430,21 @@ func (c *Config) LookupClient(server string) ([]SRV, error) {
 	default:
 		records = append(records, records2...)
 	}
-	switch {
-	case err != nil && err2 != nil:
+	if err != nil && err2 != nil {
 		return records, fmt.Errorf("failure in xmpp-client lookup: %v\n"+
 			"failure in xmpps-client lookup: %v", err, err2)
-	case err != nil:
-		return records, err
-	case err2 != nil:
-		return records, err2
 	}
 	switch len(records) {
 	case 0:
 		return records, errors.New("no client records found")
 	case 1:
-		return records, err
+		return records, nil
 	default:
 		// Sort xmpp- and xmpps-client SRV records according to the priority
 		// and weight.
 		sort.Sort(byPriority(records))
 	}
-	return records, err
+	return records, nil
 }
 
 // LookupServer returns the xmpp-server and xmpps-server SRV records sorted by
@@ -544,10 +452,6 @@ func (c *Config) LookupClient(server string) ([]SRV, error) {
 func LookupServer(server string) ([]SRV, error) {
 	var err, err2 error
 	rand.Seed(time.Now().UnixNano())
-	cname, err := getCNAME(server)
-	if err == nil {
-		server = cname
-	}
 	// Look up xmpp-client SRV
 	records, err := getSRV(server, "xmpp-server")
 	// Look up xmpps-client SRV records.
@@ -560,50 +464,36 @@ func LookupServer(server string) ([]SRV, error) {
 	default:
 		records = append(records, records2...)
 	}
-	switch {
-	case err != nil && err2 != nil:
+	if err != nil && err2 != nil {
 		return records, fmt.Errorf("failure in xmpp-server lookup: %v\n"+
 			"failure in xmpps-server lookup: %v", err, err2)
-	case err != nil:
-		return records, err
-	case err2 != nil:
-		return records, err2
 	}
 	switch len(records) {
 	case 0:
 		return records, errors.New("no server records found")
 	case 1:
-		return records, err
+		return records, nil
 	default:
 		// Sort xmpp- and xmpps-server SRV records according to the priority
 		// and weight.
 		sort.Sort(byPriority(records))
 	}
-	return records, err
+	return records, nil
 }
 
 // LookupServer returns the xmpp-server and xmpps-server SRV records sorted by
 // priority and weight.
 func (c *Config) LookupServer(server string) ([]SRV, error) {
-	var cname string
 	var records, records2 []SRV
 	var err, err2 error
 	rand.Seed(time.Now().UnixNano())
 	switch {
 	case c.Resolver == "":
-		cname, err = getCNAME(server)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRV(server, "xmpp-server")
 		// Look up xmpps-client SRV records.
 		records2, err2 = getSRV(server, "xmpps-server")
 	case c.Resolver != "" && !c.DoT:
-		cname, err = getCNAMECustomResolver(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRVCustomResolver(server, "xmpp-server",
 			c.Resolver)
@@ -611,10 +501,6 @@ func (c *Config) LookupServer(server string) ([]SRV, error) {
 		records2, err2 = getSRVCustomResolver(server, "xmpps-server",
 			c.Resolver)
 	case c.Resolver != "" && c.DoT:
-		cname, err = getCNAMEDoT(server, c.Resolver)
-		if err == nil {
-			server = cname
-		}
 		// Look up xmpp-client SRV
 		records, err = getSRVDoT(server, "xmpp-server", c.Resolver)
 		// Look up xmpps-client SRV records.
@@ -630,24 +516,19 @@ func (c *Config) LookupServer(server string) ([]SRV, error) {
 	default:
 		records = append(records, records2...)
 	}
-	switch {
-	case err != nil && err2 != nil:
+	if err != nil && err2 != nil {
 		return records, fmt.Errorf("failure in xmpp-server lookup: %v\n"+
 			"failure in xmpps-server lookup: %v", err, err2)
-	case err != nil:
-		return records, err
-	case err2 != nil:
-		return records, err2
 	}
 	switch len(records) {
 	case 0:
 		return records, errors.New("no server records found")
 	case 1:
-		return records, err
+		return records, nil
 	default:
 		// Sort xmpp- and xmpps-server SRV records according to the priority
 		// and weight.
 		sort.Sort(byPriority(records))
 	}
-	return records, err
+	return records, nil
 }
